==> flowable-http-common-6.7.2-sources.jar: org/flowable/http/common/api/HttpResponse.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.http.common.api;

/**
 * @author Harsha Teja Kanna.
 */
public class HttpResponse {

    protected int statusCode;
    protected String protocol;
    protected String reason;
    protected HttpHeaders httpHeaders;
    protected String body;
    protected boolean bodyResponseHandled;

    public HttpResponse() {
    }

    public HttpResponse(int statusCode) {
        this(statusCode, null);
    }

    public HttpResponse(int statusCode, String headers) {
        this.statusCode = statusCode;
        this.httpHeaders = HttpHeaders.parseFromString(headers);
    }

    public int getStatusCode() {
        return statusCode;
    }

    public void setStatusCode(int statusCode) {
        this.statusCode = statusCode;
    }

    public String getProtocol() {
        return protocol;
    }

    public void setProtocol(String protocol) {
        this.protocol = protocol;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public HttpHeaders getHttpHeaders() {
        return httpHeaders;
    }

    public String getHttpHeadersAsString() {
        return httpHeaders != null ? httpHeaders.formatAsString() : null;
    }

    public void setHttpHeaders(HttpHeaders httpHeaders) {
        this.httpHeaders = httpHeaders;
    }

    public String getBody() {
        return body;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public boolean isBodyResponseHandled() {
        return bodyResponseHandled;
    }

    public void setBodyResponseHandled(boolean bodyResponseHandled) {
        this.bodyResponseHandled = bodyResponseHandled;
    }
}

==> flowable-http-common-7.1.0-sources.jar: org/flowable/http/common/api/HttpResponse.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.http.common.api;

/**
 * @author Harsha Teja Kanna.
 */
public class HttpResponse {

    protected int statusCode;
    protected String protocol;
    protected String reason;
    protected HttpHeaders httpHeaders;
    protected String body;
    protected byte[] bodyBytes;
    protected boolean bodyResponseHandled;

    public HttpResponse() {
    }

    public HttpResponse(int statusCode) {
        this(statusCode, null);
    }

    public HttpResponse(int statusCode, String headers) {
        this.statusCode = statusCode;
        this.httpHeaders = HttpHeaders.parseFromString(headers);
    }

    public int getStatusCode() {
        return statusCode;
    }

    public void setStatusCode(int statusCode) {
        this.statusCode = statusCode;
    }

    public String getProtocol() {
        return protocol;
    }

    public void setProtocol(String protocol) {
        this.protocol = protocol;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public HttpHeaders getHttpHeaders() {
        return httpHeaders;
    }

    public String getHttpHeadersAsString() {
        return httpHeaders != null ? httpHeaders.formatAsString() : null;
    }

    public void setHttpHeaders(HttpHeaders httpHeaders) {
        this.httpHeaders = httpHeaders;
    }

    public String getBody() {
        return body;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public byte[] getBodyBytes() {
        return bodyBytes;
    }

    public void setBodyBytes(byte[] bodyBytes) {
        this.bodyBytes = bodyBytes;
    }

    public boolean isBodyResponseHandled() {
        return bodyResponseHandled;
    }

    public void setBodyResponseHandled(boolean bodyResponseHandled) {
        this.bodyResponseHandled = bodyResponseHandled;
    }
}
